"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  The OpenAPI Specification in YAML format is available on [www](https://www.agilicus.com/www/api/agilicus-openapi.yaml) for importing to other tools.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2025.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import agilicus_api
from agilicus_api.api.regions_api import RegionsApi  # noqa: E501


class TestRegionsApi(unittest.TestCase):
    """RegionsApi unit test stubs"""

    def setUp(self):
        self.api = RegionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_cluster(self):
        """Test case for add_cluster

        Add a Cluster  # noqa: E501
        """
        pass

    def test_add_point_of_presence(self):
        """Test case for add_point_of_presence

        Add a point of presence.  # noqa: E501
        """
        pass

    def test_add_region(self):
        """Test case for add_region

        Add a Region  # noqa: E501
        """
        pass

    def test_delete_cluster(self):
        """Test case for delete_cluster

        Delete a Cluster  # noqa: E501
        """
        pass

    def test_delete_point_of_presence(self):
        """Test case for delete_point_of_presence

        Delete a point of presence  # noqa: E501
        """
        pass

    def test_delete_region(self):
        """Test case for delete_region

        Delete a Region  # noqa: E501
        """
        pass

    def test_get_cluster(self):
        """Test case for get_cluster

        Get a Cluster  # noqa: E501
        """
        pass

    def test_get_point_of_presence(self):
        """Test case for get_point_of_presence

        Get a point of presence  # noqa: E501
        """
        pass

    def test_get_region(self):
        """Test case for get_region

        Get a Region  # noqa: E501
        """
        pass

    def test_list_clusters(self):
        """Test case for list_clusters

        List all Clusters  # noqa: E501
        """
        pass

    def test_list_point_of_presences(self):
        """Test case for list_point_of_presences

        List all regions  # noqa: E501
        """
        pass

    def test_list_regions(self):
        """Test case for list_regions

        List all regions  # noqa: E501
        """
        pass

    def test_replace_cluster(self):
        """Test case for replace_cluster

        update a Cluster  # noqa: E501
        """
        pass

    def test_replace_point_of_presence(self):
        """Test case for replace_point_of_presence

        update a point of presence  # noqa: E501
        """
        pass

    def test_replace_region(self):
        """Test case for replace_region

        update a Region  # noqa: E501
        """
        pass

    def test_routing_request(self):
        """Test case for routing_request

        Request routing  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
